@@ -1,6 +1,6 @@
-/* $Id: gucharmap.h,v 1.7 2004/01/30 07:33:04 nlevitt Exp $ */
 /*
- * Copyright (c) 2004 Noah Levitt
+ * Copyright © 2004 Noah Levitt
+ * Copyright © 2008 Christian Persch
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -14,22 +14,38 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+ * 59 Temple Place, Suite 330, Boston, MA 02110-1301  USA
  */
 
 #ifndef GUCHARMAP_H
 #define GUCHARMAP_H
 
-#include <gucharmap/gucharmap-table.h>
-#include <gucharmap/gucharmap-charmap.h>
-#include <gucharmap/gucharmap-window.h>
-#include <gucharmap/gucharmap-unicode-info.h>
-#include <gucharmap/gucharmap-mini-fontsel.h>
+#define __GUCHARMAP_GUCHARMAP_H_INSIDE__
+
+#define GUCHARMAP_VERSION_MAJOR (2)
+#define GUCHARMAP_VERSION_MINOR (23)
+#define GUCHARMAP_VERSION_MICRO (6)
+
+#define GUCHARMAP_CHECK_VERSION(major,minor,micro) \
+  (GUCHARMAP_VERSION_MAJOR > (major) || \
+   (GUCHARMAP_VERSION_MAJOR == (major) && GUCHARMAP_VERSION_MINOR > (minor)) || \
+   (GUCHARMAP_VERSION_MAJOR == (major) && GUCHARMAP_VERSION_MINOR == (minor) && GUCHARMAP_VERSION_MICRO >= (micro)))
+
 #include <gucharmap/gucharmap-codepoint-list.h>
+#include <gucharmap/gucharmap-block-codepoint-list.h>
 #include <gucharmap/gucharmap-script-codepoint-list.h>
-#include <gucharmap/gucharmap-chapters.h>
-#include <gucharmap/gucharmap-block-chapters.h>
-#include <gucharmap/gucharmap-script-chapters.h>
-#include <gucharmap/gucharmap-search-dialog.h>
+
+#include <gucharmap/gucharmap-chapters-model.h>
+#include <gucharmap/gucharmap-block-chapters-model.h>
+#include <gucharmap/gucharmap-script-chapters-model.h>
+
+#include <gucharmap/gucharmap-chartable.h>
+#include <gucharmap/gucharmap-charmap.h>
+
+#include <gucharmap/gucharmap-type-builtins.h>
+
+#include <gucharmap/gucharmap-unicode-info.h>
+
+#undef __GUCHARMAP_GUCHARMAP_H_INSIDE__
 
 #endif /* #ifndef GUCHARMAP_H */
